@@ -5,6 +5,7 @@ from dataclasses import dataclass, field
 import numpy as np
 import quaternion
 from tqdm import tqdm
+from typing import Optional
 
 from ..record import Record, FrameSample, RawSample
 from ..samples.unity.transform_pb2 import TransformCreate, TransformUpdate, TransformDestroy
@@ -34,19 +35,19 @@ class Transform:
     _local_T_mtx: np.ndarray = field(default_factory=lambda: np.eye(4, dtype=np.float32))
     _local_R_mtx: np.ndarray = field(default_factory=lambda: np.eye(4, dtype=np.float32))
     _local_S_mtx: np.ndarray = field(default_factory=lambda: np.eye(4, dtype=np.float32))
-    _parent: Transform | None = None
-    _dirty: bool = True
-
     _local_to_world_mtx: np.ndarray = None
+    _parent: Optional[Transform] = None
+    _dirty: bool = True
 
     def copy(self) -> Transform:
         parent_copy = None if self._parent is None else self._parent.copy()
-        copy = Transform(self._local_position, self._local_rotation, self._local_scale,
-                         self._local_T_mtx, self._local_R_mtx, self._local_S_mtx,
-                         parent_copy, self._dirty, self._local_to_world_mtx)
+        copy = Transform(_local_position=self._local_position, _local_rotation=self._local_rotation,
+                         _local_scale=self._local_scale, _local_T_mtx=self._local_T_mtx, _local_R_mtx=self._local_R_mtx,
+                         _local_S_mtx=self._local_S_mtx, _parent=parent_copy, _dirty=self._dirty,
+                         _local_to_world_mtx=self._local_to_world_mtx)
         return copy
 
-    def _is_dirty(self):
+    def _is_dirty(self) -> bool:
         return self._dirty or self._parent is not None and self._parent._is_dirty()
 
     def set_local_position(self, local_position: np.ndarray):
@@ -66,14 +67,23 @@ class Transform:
         self._local_scale = local_scale
         self._dirty = True
 
-    def set_parent(self, parent: Transform | None):
+    def get_local_position(self) -> np.ndarray:
+        return self._local_position
+
+    def get_local_rotation(self) -> quaternion:
+        return self._local_rotation
+
+    def get_local_scale(self) -> np.ndarray:
+        return self._local_scale
+
+    def set_parent(self, parent: Optional[Transform]):
         self._parent = parent
         self._dirty = True
 
-    def get_parent(self):
+    def get_parent(self) -> Optional[Transform]:
         return self._parent
 
-    def get_local_to_world_matrix(self):
+    def get_local_to_world_matrix(self) -> np.ndarray:
         if self._is_dirty() or self._local_to_world_mtx is None:
 
             trs_mtx = self._local_T_mtx @ self._local_R_mtx @ self._local_S_mtx
@@ -87,13 +97,13 @@ class Transform:
 
         return self._local_to_world_mtx
 
-    def get_world_translation(self):
+    def get_world_position(self) -> np.ndarray:
         return self.get_local_to_world_matrix()[0:3, 3].transpose()
 
-    def get_world_rotation(self):
+    def get_world_rotation(self) -> quaternion:
         return quaternion.from_rotation_matrix(self.get_local_to_world_matrix()[0:3, 0:3])
 
-    def get_world_scale(self):
+    def get_world_scale(self) -> np.ndarray:
         local_to_world_mtx = self.get_local_to_world_matrix()
         sx = np.linalg.norm(local_to_world_mtx[0:3, 0])
         sy = np.linalg.norm(local_to_world_mtx[0:3, 1])
@@ -108,8 +118,26 @@ class TimestampedTransform:
     frame_number: int
     transform: Transform
 
+    def get_local_position(self) -> np.ndarray:
+        return self.transform.get_local_position()
 
-def compute_transform_time_series(record: Record, guid: str):
+    def get_local_rotation(self) -> quaternion:
+        return self.transform.get_local_rotation()
+
+    def get_local_scale(self) -> np.ndarray:
+        return self.transform.get_local_scale()
+
+    def get_world_position(self) -> np.ndarray:
+        return self.transform.get_world_position()
+
+    def get_world_rotation(self) -> quaternion:
+        return self.transform.get_world_rotation()
+
+    def get_world_scale(self) -> np.ndarray:
+        return self.transform.get_world_scale()
+
+
+def compute_transform_time_series(record: Record, guid: str) -> list[TimestampedTransform]:
     transform_time_series = compute_transforms_time_series(record, {guid})
     return transform_time_series.get(guid, {})
 
